@@ -80,7 +80,7 @@ def update_env():
             )
             update_env()
     """
-    assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now."
+    assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now. (%s)" % env.hosts
     user, host, port = normalize(env.hosts[0])
 
     HOME_DIR = '/home/%s' % user
