@@ -4,18 +4,19 @@ from fab_deploy.utils import run_as, inside_project
 
 @inside_project
 def pip(commands=''):
+    """ Runs pip command """
     run('pip '+ commands)
 
 @inside_project
 def pip_install(what='active', options='', restart=True):
-    """ Installs pip requirements listed in reqs/<file>.txt file. """
+    """ Installs pip requirements listed in ``reqs/<file>.txt`` file. """
     run('pip install %s -r reqs/%s.txt' % (options, what))
     if restart:
         touch()
 
 @inside_project
 def pip_update(what='active', options='', restart=True):
-    """ Updates pip requirements listed in reqs/<file>.txt file. """
+    """ Updates pip requirements listed in ``reqs/<file>.txt`` file. """
     run('pip install %s -U -r reqs/%s.txt' % (options, what))
     if restart:
         touch()
